<?php
//Adds a box to the main column on the Page edit screens
function ng_theme_add_custom_box() 
{
    add_meta_box( 
        "options",
        __("Options", 'nostalgia'),
        "ng_theme_inner_custom_box",
        "page",
		"normal",
		"high"
    );
}
add_action("add_meta_boxes", "ng_theme_add_custom_box");
//backwards compatible (before WP 3.0)
//add_action("admin_init", "theme_add_custom_box", 1);

// Prints the box content
function ng_theme_inner_custom_box($post)
{
	//Use nonce for verification
	wp_nonce_field(plugin_basename( __FILE__ ), "nostalgia_noncename");

	//The actual fields for data entry
	$icon = get_post_meta($post->ID, "nostalgia_icon", true);
	$direction = get_post_meta($post->ID, "nostalgia_direction", true);
	$color = get_post_meta($post->ID, "nostalgia_color", true);
	$blog_categories = get_post_meta($post->ID, "nostalgia_blog_categories", true);
	$blog_order = get_post_meta($post->ID, "nostalgia_blog_order", true);
	$post_categories = get_terms("category");
	echo '
	<table>
			<tr>
			<td>
				<label>'.__('Background image:','nostalgia').'</label>
			</td>
			<td>
				<input class="regular-text" type="text" id="background_img" name="background_img" value="' . esc_attr(get_post_meta($post->ID, "nostalgia_background_img", true)) . '" />
				<input type="button" class="button" name="nostalgia_upload_button" id="background_url_button" value="'.esc_attr__('Browse','nostalgia').'" />
			</td>
		</tr> 	
						
		<tr>
			<td>
				<label for="icon">' . __('Icon', 'nostalgia') . ':</label>
			</td>
			<td>
				<select style="width: 120px;" id="icon" name="icon">
					<option value=""' . ($icon=="" ? ' selected="selected"' : '') . '>-</option>
					<option value="checkmark"' . ($icon=="checkmark" ? ' selected="selected"' : '') . '>' . __('checkmark', 'nostalgia') . '</option>
					<option value="features"' . ($icon=="features" ? ' selected="selected"' : '') . '>' . __('features', 'nostalgia') . '</option>
					<option value="image"' . ($icon=="image" ? ' selected="selected"' : '') . '>' . __('image', 'nostalgia') . '</option>
					<option value="info"' . ($icon=="info" ? ' selected="selected"' : '') . '>' . __('info', 'nostalgia') . '</option>
					<option value="mail"' . ($icon=="mail" ? ' selected="selected"' : '') . '>' . __('mail', 'nostalgia') . '</option>
					<option value="people"' . ($icon=="people" ? ' selected="selected"' : '') . '>' . __('people', 'nostalgia') . '</option>
				</select>
			</td>
		</tr>
		<tr>
			<td>
				<label for="direction">' . __('Direction', 'nostalgia') . ':</label>
			</td>
			<td>
				<select style="width: 120px;" id="direction" name="direction">
					<option value="left"' . ($direction=="left" ? ' selected="selected"' : '') . '>' . __('left', 'nostalgia') . '</option>
					<option value="right"' . ($direction=="right" ? ' selected="selected"' : '') . '>' . __('right', 'nostalgia') . '</option>
				</select>
			</td>
		</tr>
		<tr>
			<td>
				<label for="color">' . __('Custom background color', 'nostalgia') . ':</label>
			</td>
			<td>
				<input class="regular-text" type="text" id="color" name="color" value="' . esc_attr(get_post_meta($post->ID, "nostalgia_color", true)) . '" />
			</td>
		</tr>
		<tr>
			<td>
				<label for="custom_url">' . __('Custom URL', 'nostalgia') . ':</label>
			</td>
			<td>
				<input class="regular-text" type="text" id="custom_url" name="custom_url" value="' . esc_attr(get_post_meta($post->ID, "nostalgia_custom_url", true)) . '" />
			</td>
		</tr>';
		if(count($post_categories))
		{
			echo '
		<tr>
			<td>
				<label for="blog_categories">' . __('Blog categories', 'nostalgia') . ':</label>
			</td>
			<td>
				<select id="blog_categories" name="blog_categories[]" multiple="multiple">';
					foreach($post_categories as $post_category)
						echo '<option value="' . esc_attr($post_category->term_id) . '"' . (is_array($blog_categories) && in_array($post_category->term_id, $blog_categories) ? ' selected="selected"' : '') . '>' . $post_category->name . '</option>';
			echo '
				</select>
			</td>
		</tr>';
		}
		echo '
		<tr>
			<td>
				<label for="blog_order">' . __('Blog order', 'nostalgia') . ':</label>
			</td>
			<td>
				<select style="width: 120px;" id="blog_order" name="blog_order">
					<option value="asc"' . ($blog_order=="asc" ? ' selected="selected"' : '') . '>' . __('ascending', 'nostalgia') . '</option>
					<option value="desc"' . ($blog_order=="desc" ? ' selected="selected"' : '') . '>' . __('descending', 'nostalgia') . '</option>
				</select>
			</td>
		</tr>
	</table>
	';
}

//When the post is saved, saves our custom data
function ng_theme_save_postdata($post_id) 
{
	// verify if this is an auto save routine. 
	// If it is our form has not been submitted, so we dont want to do anything
	if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE) 
		return;

	//verify this came from the our screen and with proper authorization,
	//because save_post can be triggered at other times
	if (!isset($_POST['nostalgia_noncename']) || !wp_verify_nonce($_POST['nostalgia_noncename'], plugin_basename( __FILE__ )))
		return;


	// Check permissions
	if(!current_user_can('edit_post', $post_id))
		return;
		
	//OK, we're authenticated: we need to find and save the data
	update_post_meta($post_id, "nostalgia_background_img", (isset($_POST["background_img"]) ? $_POST["background_img"] : ''));
	update_post_meta($post_id, "nostalgia_icon", (isset($_POST["icon"]) ? $_POST["icon"] : ''));
	update_post_meta($post_id, "nostalgia_direction", (isset($_POST["direction"]) ? $_POST["direction"] : ''));
	update_post_meta($post_id, "nostalgia_color", (isset($_POST["color"]) ? $_POST["color"] : ''));
	update_post_meta($post_id, "nostalgia_custom_url", (isset($_POST["custom_url"]) ? $_POST["custom_url"] : ''));
	update_post_meta($post_id, "nostalgia_blog_categories", (isset($_POST["blog_categories"]) ? $_POST["blog_categories"] : ''));
	update_post_meta($post_id, "nostalgia_blog_order", (isset($_POST["blog_order"]) ? $_POST["blog_order"] : ''));
}
add_action("save_post", "ng_theme_save_postdata");
?>