<?php
//Adds a box to the main column on the Post edit screens
function ng_theme_add_post_custom_box() 
{
    add_meta_box( 
        "options",
        __("Options", 'nostalgia'),
        "ng_theme_inner_custom_post_box",
        "post",
		"normal",
		"high"
    );
}
add_action("add_meta_boxes", "ng_theme_add_post_custom_box");
//backwards compatible (before WP 3.0)
//add_action("admin_init", "theme_add_custom_box", 1);

// Prints the box content
function ng_theme_inner_custom_post_box($post)
{
	//Use nonce for verification
	wp_nonce_field(plugin_basename( __FILE__ ), "nostalgia_noncename");

	//The actual fields for data entry
	$images = get_post_meta($post->ID, "nostalgia_images", true);
	$images_titles = get_post_meta($post->ID, "nostalgia_images_titles", true);
	$features_images_loop = get_post_meta($post->ID, "nostalgia_features_images_loop", true);
	$show_images_in = get_post_meta($post->ID, "nostalgia_show_images_in", true);
	echo '
	<table>
		<tbody>
			<tr valign="top">
				<th colspan="2" scope="row" style="font-weight: bold;">
					' . __('Additional featured images', 'nostalgia') . '
				</th>
			</tr>';
			$images_count = count(array_values(array_filter((array)$images)));
			if($images_count==0)
				$images_count = 3;
			for($i=0; $i<$images_count; $i++)
			{
			echo '
			<tr class="image_url_row">
				<td>
					<label>' . __('Image url', 'nostalgia') . " " . ($i+1) . '</label>
				</td>
				<td>
					<input class="regular-text" type="text" id="nostalgia_image_url_' . absint($i+1) . '" name="images[]" value="' . (isset($images[$i]) ? esc_attr($images[$i]) : '') . '" />
					<input type="button" class="button" name="nostalgia_upload_button" id="nostalgia_image_url_button_' . absint($i+1) . '" value="' . esc_attr__('Browse', 'nostalgia') . '" />
				</td>
			</tr>
			<tr class="image_title_row">
				<td>
					<label>' . __('Image title', 'nostalgia') . " " . ($i+1) . '</label>
				</td>
				<td>
					<input class="regular-text" type="text" id="nostalgia_image_title_' . absint($i+1) . '" name="images_titles[]" value="' . (isset($images_titles[$i]) ? esc_attr($images_titles[$i]) : '') . '" />
				</td>
			</tr>';
			}
			echo '
			<tr>
				<td></td>
				<td>
					<input type="button" class="button" name="nostalgia_add_new_button" id="nostalgia_add_new_button_image" value="' . esc_attr__('Add image', 'nostalgia') . '" />
				</td>
			</tr>
			<tr>
				<td>
					<label for="features_images_loop">' . __('Features images loop', 'nostalgia') . ':</label>
				</td>
				<td>
					<select id="features_images_loop" name="features_images_loop">
						<option value="yes"' . ($features_images_loop=="yes" ? ' selected="selected"' : '') . '>' . __('yes', 'nostalgia') . '</option>
						<option value="no"' . ($features_images_loop=="no" ? ' selected="selected"' : '') . '>' . __('no', 'nostalgia') . '</option>
					</select>
				</td>
			</tr>
			<tr>
				<td>
					' . __('Show featured images lightbox', 'nostalgia') . '
				</td>
				<td>
					<select id="show_images_in" name="show_images_in">
						<option value="blog"' . ($show_images_in=="blog" ? ' selected="selected"' : '') . '>' . __('on post list', 'nostalgia') . '</option>
						<option value="post"' . ($show_images_in=="post" ? ' selected="selected"' : '') . '>' . __('in single post', 'nostalgia') . '</option>
						<option value="both"' . ($show_images_in=="both" ? ' selected="selected"' : '') . '>' . __('both', 'nostalgia') . '</option>
					</select>
				</td>
			</tr>
		</tbody>
	</table>
	';
}

//When the post is saved, saves our custom data
function ng_theme_save_post_postdata($post_id) 
{
	// verify if this is an auto save routine. 
	// If it is our form has not been submitted, so we dont want to do anything
	if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE) 
		return;

	//verify this came from the our screen and with proper authorization,
	//because save_post can be triggered at other times
	if (!isset($_POST['nostalgia_noncename']) || !wp_verify_nonce($_POST['nostalgia_noncename'], plugin_basename( __FILE__ )))
		return;


	// Check permissions
	if(!current_user_can('edit_post', $post_id))
		return;
		
	//OK, we're authenticated: we need to find and save the data
	update_post_meta($post_id, "nostalgia_images", array_filter($_POST["images"]));
	update_post_meta($post_id, "nostalgia_images_titles", array_filter($_POST["images_titles"]));
	update_post_meta($post_id, "nostalgia_features_images_loop", $_POST["features_images_loop"]);
	update_post_meta($post_id, "nostalgia_show_images_in", $_POST["show_images_in"]);
}
add_action("save_post", "ng_theme_save_post_postdata");
?>